/*
** Copyright (C) 10 Feb 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

config_cdr_data *create_cdrecord_options(GtkWidget *);
GtkWidget *select_speed(GtkWidget *);

extern GtkWidget *dummy, *eject, *pad, *swab_audio, *dao, *no_image, *use_image, *audio_tracks;
extern GtkWidget *audio_tracks_combo, *image_path, *copy_iso_cd, *iso_device_path, *copy_audio_cd;
extern GtkWidget *blank_all, *blank_fast, *audio_device_path, *disable_fixate;
extern GtkWidget *fsentry, *need_track_size, *enable_burnproof, *speed_spin;
extern char *def_image_path;

